summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/tree.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/oblique/tree.cpp')
-rw-r--r--noatun-plugins/oblique/tree.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/noatun-plugins/oblique/tree.cpp b/noatun-plugins/oblique/tree.cpp
index 7f3415c..0087b99 100644
--- a/noatun-plugins/oblique/tree.cpp
+++ b/noatun-plugins/oblique/tree.cpp
@@ -180,7 +180,7 @@ TreeItem::~TreeItem()
tree()->mPlayableItemCount--;
}
// I have to remove my tqchildren, because they need their parent
// in tact for the below code
while (TreeItem *c = firstChild())
delete c;
@@ -750,36 +750,36 @@ TreeItem *Tree::collate(TreeItem *fix, QueryGroup *group, const File &file, Tree
TreeItem *Tree::node(TreeItem *fix, QueryGroup *group, const File &file, TreeItem *childOf)
{
- // search childOf's immediate tqchildren
- TreeItem *tqchildren;
+ // search childOf's immediate children
+ TreeItem *children;
if (childOf)
- tqchildren = childOf->firstChild();
+ children = childOf->firstChild();
else
- tqchildren = firstChild();
+ children = firstChild();
TQString presentation = group->presentation(file);
- while (tqchildren)
+ while (children)
{
// merging would be done here
bool matches=false;
if (group->fuzzyness(QueryGroup::Case))
{
- matches = (tqchildren->text(0).lower() == presentation.lower());
+ matches = (children->text(0).lower() == presentation.lower());
}
else
{
- matches = (tqchildren->text(0) == presentation);
+ matches = (children->text(0) == presentation);
}
- matches = matches && !tqchildren->group()->option(QueryGroup::Playable);
+ matches = matches && !children->group()->option(QueryGroup::Playable);
if (matches)
{
- tqchildren->setFile(File());
- return tqchildren;
+ children->setFile(File());
+ return children;
}
- tqchildren = tqchildren->nextSibling();
+ children = children->nextSibling();
}
TreeItem *item;
@@ -180,7 +180,7 @@ TreeItem::~TreeItem()
tree()->mPlayableItemCount--;
}
- // I have to remove my tqchildren, because they need their parent
+ // I have to remove my children, because they need their parent
// in tact for the below code
while (TreeItem *c = firstChild())